# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

import base64, codecs
magic = 'IyBQYXJ0IG9mIHRoZSBST0JPSUQgcHJvamVjdCAtIGh0dHA6Ly9oYW1zdGVyLnNjaG9vbAojIENvcHlyaWdodCAoQykgMjAxNiBLd2FuZy1IeXVuIFBhcmsgKGFrYWlpQGt3LmFjLmtyKQojIAojIFRoaXMgbGlicmFyeSBpcyBmcmVlIHNvZnR3YXJlOyB5b3UgY2FuIHJlZGlzdHJpYnV0ZSBpdCBhbmQvb3IKIyBtb2RpZnkgaXQgdW5kZXIgdGhlIHRlcm1zIG9mIHRoZSBHTlUgTGVzc2VyIEdlbmVyYWwgUHVibGljCiMgTGljZW5zZSBhcyBwdWJsaXNoZWQgYnkgdGhlIEZyZWUgU29mdHdhcmUgRm91bmRhdGlvbjsgZWl0aGVyCiMgdmVyc2lvbiAyLjEgb2YgdGhlIExpY2Vuc2UsIG9yIChhdCB5b3VyIG9wdGlvbikgYW55IGxhdGVyIHZlcnNpb24uCiMgCiMgVG'
love = 'ucplOfnJWlLKW5VTymVTEcp3ElnJW1qTIxVTyhVUEbMFObo3OyVUEbLKDtnKDtq2yfoPOvMFO1p2IzqJjfPvZtLaI0VSqWIRuCIIDtDH5MVSqOHyWOGyEMBlO3nKEbo3I0VTI2MJ4tqTuyVTygpTkcMJDtq2SlpzShqUxto2LXVlOAEIWQFRSBIRSPFHkWISxto3VtExyHGxIGHlOTG1VtDFODDIWHFHAIGRSFVSOIHyOCH0HhVPOGMJHtqTuyVRqBIDbwVRkyp3AypvOUMJ5ypzSfVSO1LzkcLlOZnJAyoaAyVTMipvOgo3WyVTEyqTScoUZhPvZtPvZtJJ91VUAbo3IfMPObLKMyVUWyL2IcqzIxVTRtL29jrFOiMvO0nTHtE05IVRkyp3AypvOUMJ5ypzSfPvZtHUIvoTywVRkcL2Ihp2HtLJkiozptq2y0nPO0nTymVTkcLaWupax7VTyzVT5iqPjtq3WcqTHtqT8tqTuyPvZt'
god = 'RnJlZSBTb2Z0d2FyZSBGb3VuZGF0aW9uLCBJbmMuLCA1OSBUZW1wbGUgUGxhY2UsIFN1aXRlIDMzMCwKIyBCb3N0b24sIE1BICAwMjExMS0xMzA3ICBVU0EKCgpmcm9tIHNrbGVhcm4ubmVpZ2hib3JzIGltcG9ydCBLTmVpZ2hib3JzQ2xhc3NpZmllcgppbXBvcnQgbnVtcHkgYXMgbnAKCgpjbGFzcyBLbm46CiAgICBkZWYgX19pbml0X18oc2VsZiwgbmVpZ2hib3JzPTMpOgogICAgICAgIHNlbGYuX21vZGVsID0gS05laWdoYm9yc0NsYXNzaWZpZXIobl9uZWlnaGJvcnM9bmVpZ2hib3JzKQogICAgICAgIHNlbGYuY2xlYXIoKQoKICAgIGRlZiBjbGVhcihzZWxmKToKICAgICAgICBzZWxmLl9sYWJlbHMgPSBbXQogICAgICAgIHNlbGYuX3RyYWluX2RhdGEgPS'
destiny = 'OoKDbXVPNtVTEyMvOfo2SxK3ElLJyhXUAyoTLfVTkuLzIfYPOznJkypTS0nPx6PvNtVPNtVPNtMTS0LFN9VT5jYzkiLJE0rUDbMzyfMKOuqTtfVTEyoTygnKEypw0aYPpcPvNtVPNtVPNtp2IfMv5sqUWunJ5sMTS0LF5yrUEyozDbMTS0LFxXVPNtVPNtVPOfLJWyoUZtCFOooTSvMJkqVPbtMTS0LF5mnTSjMIfjKDbtVPNtVPNtVUAyoTLhK2kuLzIfpl5yrUEyozDboTSvMJkmXDbXVPNtVTEyMvO0pzScovumMJkzXGbXVPNtVPNtVPOmMJkzYy9go2EyoP5znKDbp2IfMv5sqUWunJ5sMTS0LFjtp2IfMv5soTSvMJkmXDbXVPNtVTEyMvOjpzIxnJA0XUAyoTLfVUMyL3Eipvx6PvNtVPNtVPNtpzI0qKWhVUAyoTLhK21iMTIfYaOlMJEcL3DbJ3MyL3Eipy0cJmOqPt=='
joy = '\x72\x6f\x74\x31\x33'
trust = eval('\x6d\x61\x67\x69\x63') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x6c\x6f\x76\x65\x2c\x20\x6a\x6f\x79\x29') + eval('\x67\x6f\x64') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x64\x65\x73\x74\x69\x6e\x79\x2c\x20\x6a\x6f\x79\x29')
eval(compile(base64.b64decode(eval('\x74\x72\x75\x73\x74')),'<string>','exec'))


# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

import roboidai.lab._image as _image
import roboidai.lab._line_recorder as _line_recorder
import roboidai.lab._q_world as _q_world
from roboidai.lab._q_world import QWorld
import roboidai.lab._zoo as _zoo
import roboidai.lab._track as _track
from roboidai.lab._tree import Node


def collect_image(cam, folder):
    _image.collect_image(cam, folder)

def collect_color(cam, labels, color_space='hsv'):
    return _image.collect_color(cam, labels, color_space)

def capture_color(cam, color_space='hsv'):
    return _image.capture_color(cam, color_space)

def record_hamster(file_path):
    _line_recorder.record_hamster(file_path)

def record_hamster_s(file_path):
    _line_recorder.record_hamster_s(file_path)

def play_q_game_hamster():
    _q_world.play_q_game_hamster()

def play_q_game_hamster_s(cross=True):
    _q_world.play_q_game_hamster_s(cross)

def move_zoo(robot, animal):
    _zoo.move_zoo(robot, animal)

def play_zoo_cam(robot, cam, model_folder):
    _zoo.play_zoo_cam(robot, cam, model_folder)

def play_zoo_tree(robot):
    _zoo.play_zoo_tree(robot)

def find_track_xy(image, output, color, h_range, s_range=(50,255), v_range=(50,255), window_height=-1, min_area=0):
    return _track.find_track_xy(image, output, color, h_range, s_range, v_range, window_height, min_area)

def find_green_track_xy(image, output, h_range=(50, 70), s_range=(50,255), v_range=(50,255), window_height=-1, min_area=0):
    return _track.find_green_track_xy(image, output, h_range, s_range, v_range, window_height, min_area)

def find_blue_track_xy(image, output, h_range=(110, 130), s_range=(50,255), v_range=(50,255), window_height=-1, min_area=0):
    return _track.find_blue_track_xy(image, output, h_range, s_range, v_range, window_height, min_area)

def find_red_track_xy(image, output, h_range=(0, 10, 170, 180), s_range=(50,255), v_range=(50,255), window_height=-1, min_area=0):
    return _track.find_red_track_xy(image, output, h_range, s_range, v_range, window_height, min_area)



# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA


class Node:
    def __init__(self, key):
        self._key = key
        self._left = None
        self._right = None

    def is_terminal(self):
        return self._left is None and self._right is None

    def get_key(self):
        return self._key

    def set_key(self, key):
        self._key = key

    def get_left(self):
        return self._left

    def get_right(self):
        return self._right

    def add_left(self, key):
        node = Node(key)
        self._left = node
        return node

    def add_right(self, key):
        node = Node(key)
        self._right = node
        return node



# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

from roboidai._camera import Camera
from roboidai._window import Window
from roboidai._keyevent import KeyEvent
from roboidai._image._face_detector import FaceDetector
from roboidai._image._age_gender import AgeGenderDetector
from roboidai._image._expression import FacialExpression
from roboidai._image._object_detector import ObjectDetector
from roboidai._image._face_marker import FaceMarkerDetector
from roboidai._image._face_mesh import FaceMesh
from roboidai._image._hand_pose import HandPose
from roboidai._image._tool import ImageTool
from roboidai._tm._image import TmImage
from roboidai._ml._knn import Knn

__version__ = "1.1.11"

def version():
    import roboid
    import numpy as np
    import tensorflow as tf
    import cv2
    print('-' * 20)
    print('roboid:', roboid.__version__)
    print('roboidai:', __version__)
    print('numpy:', np.__version__)
    print('tensorflow:', tf.__version__)
    print('opencv:', cv2.__version__)
    print('-' * 20)

def test_camera(target='all', max_usb=10, max_ip=5, wifi_name=None, user='admin', passwd='admin'):
    Camera.test(target, max_usb, max_ip, wifi_name, user, passwd)

def test_usb_camera(max_usb=10):
    Camera.test('usb', max_usb)

def test_ip_camera(max_ip=5, wifi_name=None, user='admin', passwd='admin'):
    Camera.test('ip', 0, max_ip, wifi_name, user, passwd)



from setuptools import setup, find_packages

setup(
	name="roboidai",
	version="1.1.11",
	author="Kwang-Hyun Park",
	author_email="akaii@kw.ac.kr",
	description="Python Package for Roboid AI",
	long_description=open("README.md").read(),
	long_description_content_type="text/markdown",
	install_requires=["roboid", "ifaddr", "pyttsx3", "pynput", "pandas", "matplotlib", "scikit-learn", "numpy", "mediapipe", "fer", "opencv-python", "tensorflow"],
	packages=find_packages(exclude=["examples", "tests"]),
	python_requires=">=3",
	include_package_data=True,
	zip_safe=False,
	classifiers=[
		"License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)"
	]
)